==> qxcommon-1.0.06-sources.jar: cn/com/startai/qxcommon/busi/huadian/bean/HDUpdateUserLoginPwdReq.java <==
package cn.com.startai.qxcommon.busi.huadian.bean;

import cn.com.startai.qxcommon.busi.huadian.HDCmd;
import cn.com.startai.qxcommon.protocol.QXBaseContent;

/**
 * Created by Robin on 2019/5/25.
 * 419109715@qq.com 彬影
 */
public class HDUpdateUserLoginPwdReq extends QXBaseContent {

    /**
     * oldPassword : 16777731
     * confirmPassword : 123456
     * password : 16777731
     * <p>
     * confirmPassword：确认密码
     * password：密码
     * oldPassword:原密码
     */

    private String userId;
    private String oldPassword;
    private String confirmPassword;
    private String password;

    public HDUpdateUserLoginPwdReq() {
    }

    public HDUpdateUserLoginPwdReq(String userId, String oldPassword, String confirmPassword, String password) {
        this.userId = userId;
        this.oldPassword = oldPassword;
        this.confirmPassword = confirmPassword;
        this.password = password;
    }

    @Override
    public String toString() {
        return "HDGetTeamInfoReq{" +
                "userId='" + userId + '\'' +
                ", custom=" + custom +
                ", product=" + product +
                ", cmd=" + cmd +
                ", result=" + result +
                '}';
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    @Override
    public long getCmd() {
        return HDCmd.HD_UPDATE_USER_LOGIN_PWD;
    }

    public String getOldPassword() {
        return oldPassword;
    }

    public void setOldPassword(String oldPassword) {
        this.oldPassword = oldPassword;
    }

    public String getConfirmPassword() {
        return confirmPassword;
    }

    public void setConfirmPassword(String confirmPassword) {
        this.confirmPassword = confirmPassword;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }
}

==> qxcommon-1.0.39-sources.jar: cn/com/startai/qxcommon/busi/huadian/bean/HDUpdateUserLoginPwdReq.java <==
package cn.com.startai.qxcommon.busi.huadian.bean;

import cn.com.startai.qxcommon.busi.huadian.HDCmd;
import cn.com.startai.qxcommon.protocol.QXBaseContent;

/**
 * Created by Robin on 2019/5/25.
 * 419109715@qq.com 彬影
 */
public class HDUpdateUserLoginPwdReq extends QXBaseContent {

    /**
     * oldPassword : 16777731
     * confirmPassword : 123456
     * password : 16777731
     * <p>
     * confirmPassword：确认密码
     * password：密码
     * oldPassword:原密码
     */

    protected String userId;
    protected String oldPassword;
    protected String confirmPassword;
    protected String password;

    public HDUpdateUserLoginPwdReq() {
    }

    public HDUpdateUserLoginPwdReq(String userId, String oldPassword, String confirmPassword, String password) {
        this.userId = userId;
        this.oldPassword = oldPassword;
        this.confirmPassword = confirmPassword;
        this.password = password;
    }

    @Override
    public String toString() {
        return "HDGetTeamInfoReq{" +
                "userId='" + userId + '\'' +
                ", custom=" + custom +
                ", product=" + product +
                ", cmd=" + cmd +
                ", result=" + result +
                '}';
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    @Override
    public long getCmd() {
        return HDCmd.HD_UPDATE_USER_LOGIN_PWD;
    }

    public String getOldPassword() {
        return oldPassword;
    }

    public void setOldPassword(String oldPassword) {
        this.oldPassword = oldPassword;
    }

    public String getConfirmPassword() {
        return confirmPassword;
    }

    public void setConfirmPassword(String confirmPassword) {
        this.confirmPassword = confirmPassword;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }
}
